@@ -29,15 +29,21 @@ class BuzzerThread(threading.Thread):
             lock.release()
             if len(alarms) > 0:
                 now = datetime.now().time().replace(second=0, microsecond=0)
-                if alarms[0].time == now:
+                alarm = alarms[0]
+                if alarm.time == now:
                     lock.acquire()
-                    if self.manager.alarm_pid is None:
+                    if (
+                        not self.manager.is_canceled(alarm.time, alarm.when)
+                        and self.manager.alarm_pid is None
+                    ):
                         self.manager.alarm_pid = self.start_alarm()
                     lock.release()
-            sleep(20)
+            sleep(10)
 
     def start_alarm(self) -> int:
-        process = subprocess.Popen(["mpv", "--loop", "--no-video", self.sound])
+        process = subprocess.Popen(
+            ["mpv", "--really-quiet", "--loop", "--no-video", self.sound]
+        )
         return process.pid
 
     def finalize(self) -> None:
